# @(#)88  1.3 src/cmdline/staging/scripts/domain_utils.py, amws.cmdline, fim611, 060921a 9/18/06 16:18:32
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
                                                                                
import sys
from fim_base import FIM_TRUE, FIM_FALSE, commit_session, get_domain_instance
from com.tivoli.am.fim.middlemanager import FIMDomain, WASSecurityInfo 
from com.tivoli.am.fim.middlemanager.rtconfig import RuntimeNodesManager
from com.tivoli.am.fim.middlemanager.util import MgmtUtils
from java.io import File, FileInputStream, FileOutputStream, ByteArrayOutputStream
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array, zeros
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants

# Set up FIMLogger
component_name = "StagingTools"
script_name = "domain_utils.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)

#######
# create_domain
#
# Gets an instance of a FIMDomain object and uses it to create the domain
# on the server
#
########
def create_domain(domain):
    rtMgr = RuntimeNodesManager.getInstance("create_domain", domain)
    rtMgr.createDomain(domain)
    commit_session(rtMgr, FIM_FALSE)
    return

#######
# delete_domain
#
# Gets an instance of a FIMDomain object and uses it to delete the domain
# on the server
#
########

def delete_domain(domain):
    rtMgr = RuntimeNodesManager.getInstance("delete_domain", domain)
    rtMgr.removeDomain(domain)
    commit_session(rtMgr, FIM_FALSE)
    return 

#######
# export_configuration_archive
#
# Places a configuration archive from the specified location
# into the specified domain
#
########
def export_configuration_archive(domain, location): 
    # Set up FIMLogger
    method_name = "export_configuration_archive"

    rtMgr = RuntimeNodesManager.getInstance("export_configuration_archive", domain)
    configbytes = rtMgr.exportConfiguration()
    
    # Check to see whether file can be created
    try:
        config_archive_file = open(location, "w")
        config_archive_file.close()
    except IOError:
        inserts = array([location], Object)
        log.logMessage(FIMLevel.WARNING, method_name, 
            CmdLineMessages.unable_to_create_file, inserts)
        raise SystemExit  
    
    # Export the archive
    config_archive_file = File(location)
    stream = FileOutputStream(config_archive_file)
    stream.write(configbytes)
    return

#######
# import_configuration_archive
#
# Reads in a configuration archive from the specified location
# into the domain specified
#
########
def import_configuration_archive(domain, location): 
    # Set up FIMLogger
    method_name = "import_configuration_archive"
    
    rtMgr = RuntimeNodesManager.getInstance("import_configuration_archive", domain)
    
    try:
        config_archive_file = File(location)
        stream = FileInputStream(config_archive_file)
    except:
        inserts = array([location], Object)
        log.logMessage(FIMLevel.WARNING, method_name, 
            CmdLineMessages.file_not_found, inserts)
        raise SystemExit

    num_bytes_avail = stream.available()
    configbytes = zeros(num_bytes_avail,'b')
    num_bytes_read = stream.read(configbytes)
    if num_bytes_read:
        try:
            rtMgr.importConfiguration(configbytes, FIM_TRUE)
        except:
            log.logMessage(FIMLevel.WARNING, method_name, \
                CmdLineMessages.source_jar_not_correct_version)
            raise SystemExit
    else:
        log.logMessage(FIMLevel.WARNING, method_name, \
            CmdLineMessages.source_jar_not_correct_version)
        raise SystemExit
    commit_session(rtMgr)
    return

#######
# get_current_version
#
# Returns the version of the TFIM Runtime currently deployed.
#
########
def get_current_version(domain):    
    rtMgr = RuntimeNodesManager.getInstance("get_current_version", domain)
    version = rtMgr.getCurrentVersion()
    return version

#######
# is_domain_present
#
# Returns whether or not the domain exists
#
########
def is_domain_present(domain_props):
    method_name = "is_domain_present"
    
    domain = get_domain_instance(domain_props)
    rt_mgr = RuntimeNodesManager.getInstance(method_name, domain);
    if not rt_mgr.isDomainPresent():
	inserts = array([domain.getDomainName()], Object)
	log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.domain_does_not_exist, inserts)
        return FIM_FALSE

    return FIM_TRUE
    

